@@ -22,6 +22,7 @@
 
 // Qt
 #include <QAction>
+#include <QActionGroup>
 #include <QApplication>
 #include <QComboBox>
 #include <QDialogButtonBox>
@@ -32,7 +33,6 @@
 #include <QIcon>
 #include <QInputDialog>
 #include <QLayout>
-#include <QLinkedList>
 #include <QListWidget>
 #include <QMenu>
 #include <QMimeDatabase>
@@ -51,6 +51,7 @@
 #include <QVBoxLayout>
 
 // KDE Frameworks
+#include <kwidgetsaddons_version.h>
 #include <KPluginMetaData>
 #include <KActionCollection>
 #include <KConfigGroup>
@@ -681,22 +682,22 @@ void KImageMapEditor::setupActions()
     increaseWidthAction  = new QAction(i18n("Increase Width"), this);
     actionCollection()->addAction("increasewidth", increaseWidthAction );
   connect(increaseWidthAction, SIGNAL(triggered(bool)), SLOT(slotIncreaseWidth()));
-  actionCollection()->setDefaultShortcut(increaseWidthAction, QKeySequence(Qt::Key_Right + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(increaseWidthAction, QKeySequence(Qt::Key_Right | Qt::SHIFT));
 
     decreaseWidthAction  = new QAction(i18n("Decrease Width"), this);
     actionCollection()->addAction("decreasewidth", decreaseWidthAction );
   connect(decreaseWidthAction, SIGNAL(triggered(bool)), SLOT(slotDecreaseWidth()));
-  actionCollection()->setDefaultShortcut(decreaseWidthAction, QKeySequence(Qt::Key_Left + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(decreaseWidthAction, QKeySequence(Qt::Key_Left | Qt::SHIFT));
 
     increaseHeightAction  = new QAction(i18n("Increase Height"), this);
     actionCollection()->addAction("increaseheight", increaseHeightAction );
   connect(increaseHeightAction, SIGNAL(triggered(bool)), SLOT(slotIncreaseHeight()));
-  actionCollection()->setDefaultShortcut(increaseHeightAction, QKeySequence(Qt::Key_Up + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(increaseHeightAction, QKeySequence(Qt::Key_Up | Qt::SHIFT));
 
     decreaseHeightAction  = new QAction(i18n("Decrease Height"), this);
     actionCollection()->addAction("decreaseheight", decreaseHeightAction );
   connect(decreaseHeightAction, SIGNAL(triggered(bool)), SLOT(slotDecreaseHeight()));
-  actionCollection()->setDefaultShortcut(decreaseHeightAction, QKeySequence(Qt::Key_Down + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(decreaseHeightAction, QKeySequence(Qt::Key_Down | Qt::SHIFT));
 
     toFrontAction  = new QAction(i18n("Bring to Front"), this);
     actionCollection()->addAction("tofront", toFrontAction );
@@ -1556,7 +1557,7 @@ void KImageMapEditor::mapEditName()
   if (ok && !input.isEmpty()) {
     if (input != _mapName) {
         if (mapsListView->nameAlreadyExists(input))
-            KMessageBox::sorry(this->widget(), i18n("The name <em>%1</em> already exists.", input));
+            KMessageBox::error(this->widget(), i18n("The name <em>%1</em> already exists.", input));
         else {
             setMapName(input);
         }
@@ -1921,7 +1922,7 @@ bool KImageMapEditor::openHTMLFile(const QUrl & url)
         } else
         if (readMap) {
           if (tagName=="area") {
-             map->prepend(*attr);
+             map->push_front(*attr);
           }
         } else {
           _htmlContent.append(new HtmlElement(origcode));
@@ -2184,7 +2185,7 @@ void KImageMapEditor::saveAreasToMapTag(MapTag* map) {
 
     dict.insert("coords",a->coordsToString());
 
-    map->append(dict);
+    map->push_back(dict);
 
   }
 
@@ -2199,7 +2200,7 @@ void KImageMapEditor::saveAreasToMapTag(MapTag* map) {
       dict.insert(it.key(),it.value());
     }
 
-    map->append(dict);
+    map->push_back(dict);
   }
 
 }
@@ -2227,9 +2228,7 @@ void KImageMapEditor::setMap(HtmlMapElement* mapElement) {
     _mapName = map->name;
     AreaTag tag;
 
-    QLinkedListIterator<AreaTag> it(*map);
-    while (it.hasNext()) {
-        tag = it.next();
+    for (const AreaTag &tag : *map) {
         QString shape="rect";
         if (tag.contains("shape"))
           shape=tag.value("shape");
@@ -2738,7 +2737,11 @@ bool KImageMapEditor::queryClose() {
   if ( ! isModified() )
      return true;
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+  switch ( KMessageBox::warningTwoActionsCancel(
+#else
   switch ( KMessageBox::warningYesNoCancel(
+#endif
               widget(),
 	      i18n("<qt>The file <i>%1</i> has been modified.<br />Do you want to save it?</qt>",
 	      url().fileName()),
@@ -2746,10 +2749,18 @@ bool KImageMapEditor::queryClose() {
 	      KStandardGuiItem::save(),
 	      KStandardGuiItem::discard()) )
     {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::PrimaryAction :
+#else
     case KMessageBox::Yes :
+#endif
       saveFile();
       return true;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::SecondaryAction :
+#else
     case KMessageBox::No :
+#endif
       return true;
     default:
       return false;
